@@ -73,6 +73,10 @@
         <source>&amp;Copy Address</source>
         <translation>&amp;Dupliseer Adres</translation>
     </message>
+    <message>
+        <source>Copy &amp;Label</source>
+        <translation>Kopieer &amp;Etiket</translation>
+    </message>
     <message>
         <source>&amp;Edit</source>
         <translation>&amp;Verander</translation>
@@ -199,6 +203,14 @@
         <source>The passphrase entered for the wallet decryption was incorrect.</source>
         <translation>U het die verkeerde wagwoord ingetik.</translation>
     </message>
+    <message>
+        <source>Wallet decryption failed</source>
+        <translation>Beursie-dekripsie het misluk</translation>
+    </message>
+    <message>
+        <source>Wallet passphrase was successfully changed.</source>
+        <translation>Beursie wagwoordfrase is suksesvol verander.</translation>
+    </message>
     <message>
         <source>Warning: The Caps Lock key is on!</source>
         <translation>WAARSKUWING:  Outomatiese Kapitalisering is aktief op u sleutelbord!</translation>
@@ -206,6 +218,10 @@
 </context>
 <context>
     <name>BanTableModel</name>
+    <message>
+        <source>IP/Netmask</source>
+        <translation>IP/Netmasker</translation>
+    </message>
     <message>
         <source>Banned Until</source>
         <translation>Verban tot</translation>
@@ -213,6 +229,10 @@
 </context>
 <context>
     <name>BitcoinGUI</name>
+    <message>
+        <source>Sign &amp;message...</source>
+        <translation>Teken &amp;boodskap...</translation>
+    </message>
     <message>
         <source>Synchronizing with network...</source>
         <translation>Netwerk-sinkronisasie...</translation>
@@ -293,6 +313,18 @@
         <source>Open &amp;URI...</source>
         <translation>Oop &amp; URI...</translation>
     </message>
+    <message>
+        <source>Click to disable network activity.</source>
+        <translation>Kliek om netwerkaktiwiteit af te skakel.</translation>
+    </message>
+    <message>
+        <source>Network activity disabled.</source>
+        <translation>Netwerkaktiwiteit gedeaktiveer.</translation>
+    </message>
+    <message>
+        <source>Click to enable network activity again.</source>
+        <translation>Kliek om netwerkaktiwiteit weer aan te skakel.</translation>
+    </message>
     <message>
         <source>Reindexing blocks on disk...</source>
         <translation>Besig met herindeksering van blokke op hardeskyf...</translation>
@@ -309,6 +341,14 @@
         <source>Change the passphrase used for wallet encryption</source>
         <translation>Verander die wagwoord wat ek vir kodifikasie van my beursie gebruik</translation>
     </message>
+    <message>
+        <source>&amp;Debug window</source>
+        <translation>&amp;Ontfout venster</translation>
+    </message>
+    <message>
+        <source>Open debugging and diagnostic console</source>
+        <translation>Maak ontfouting en diagnostiese konsole oop</translation>
+    </message>
     <message>
         <source>Bitcoin</source>
         <translation>Bitcoin</translation>
