@@ -61,6 +61,14 @@
         <source>Receiving addresses</source>
         <translation>آدرس های گیرنده</translation>
     </message>
+    <message>
+        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
+        <translation>اینها آدرس های شما برای فرستادن پرداخت هاست. همیشه قبل از فرستادن سکه ها مقدار و آدرس دریافت کننده را چک کنید.</translation>
+    </message>
+    <message>
+        <source>&amp;Copy Address</source>
+        <translation>کپی کردن آدرس</translation>
+    </message>
     <message>
         <source>Copy &amp;Label</source>
         <translation>کپی و برچسب‌&amp;گذاری</translation>
@@ -69,6 +77,14 @@
         <source>&amp;Edit</source>
         <translation>&amp;ویرایش</translation>
     </message>
+    <message>
+        <source>Export Address List</source>
+        <translation>صدور لیست آدرس ها</translation>
+    </message>
+    <message>
+        <source>Exporting Failed</source>
+        <translation>صدور موفق نبود</translation>
+    </message>
     </context>
 <context>
     <name>AddressTableModel</name>
@@ -107,10 +123,18 @@
         <source>Encrypt wallet</source>
         <translation>رمزنگاری کیف پول</translation>
     </message>
+    <message>
+        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
+        <translation>این عملیات نیاز به عبارت کیف پول شما برای بازگشایی کیف پول دارد</translation>
+    </message>
     <message>
         <source>Unlock wallet</source>
         <translation>باز کردن قفل کیف پول</translation>
     </message>
+    <message>
+        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
+        <translation>این عملیات نیاز به عبارت کیف پول شما برای رمزگشایی کیف پول دارد.</translation>
+    </message>
     <message>
         <source>Decrypt wallet</source>
         <translation>رمزگشایی کیف پول</translation>
@@ -119,6 +143,10 @@
         <source>Change passphrase</source>
         <translation>تغییر گذرواژه</translation>
     </message>
+    <message>
+        <source>Enter the old passphrase and new passphrase to the wallet.</source>
+        <translation>عبارت کهنه و جدید کیف پول را وارد کنید.</translation>
+    </message>
     <message>
         <source>Confirm wallet encryption</source>
         <translation>تأیید رمزنگاری کیف پول</translation>
@@ -253,6 +281,18 @@
         <source>Open &amp;URI...</source>
         <translation>باز کردن &amp;آدرس</translation>
     </message>
+    <message>
+        <source>Click to disable network activity.</source>
+        <translation>برای غیر فعال کردن فعالیت شبکه کلیک کنید.</translation>
+    </message>
+    <message>
+        <source>Network activity disabled.</source>
+        <translation>فعالیت شبکه غیر فعال شد.</translation>
+    </message>
+    <message>
+        <source>Click to enable network activity again.</source>
+        <translation>برای فعال کردن دوباره فعالیت شبکه کلیک کنید.</translation>
+    </message>
     <message>
         <source>Reindexing blocks on disk...</source>
         <translation>بازنشانی بلوک‌ها روی دیسک...</translation>
@@ -542,6 +582,14 @@
         <source>Copy fee</source>
         <translation>رونوشت کارمزد</translation>
     </message>
+    <message>
+        <source>Copy bytes</source>
+        <translation>کپی کردن بایت ها</translation>
+    </message>
+    <message>
+        <source>Copy change</source>
+        <translation>کپی کردن تغییر</translation>
+    </message>
     <message>
         <source>(%1 locked)</source>
         <translation>(%1 قفل شده)</translation>
@@ -717,6 +765,22 @@
         <source>Last block time</source>
         <translation>زمان آخرین بلوک</translation>
     </message>
+    <message>
+        <source>Progress</source>
+        <translation>پیشروی</translation>
+    </message>
+    <message>
+        <source>Progress increase per hour</source>
+        <translation>پیشروی در هر ساعت بیشتر میشود</translation>
+    </message>
+    <message>
+        <source>calculating...</source>
+        <translation>در حال محاسبه...</translation>
+    </message>
+    <message>
+        <source>Estimated time left until synced</source>
+        <translation>زمان تخمینی تا سینک شدن</translation>
+    </message>
     <message>
         <source>Hide</source>
         <translation>پنهان کردن</translation>
@@ -937,6 +1001,10 @@
     </context>
 <context>
     <name>PaymentServer</name>
+    <message>
+        <source>Invalid payment request.</source>
+        <translation>درخواست پرداخت نامعتبر.</translation>
+    </message>
     </context>
 <context>
     <name>PeerTableModel</name>
@@ -1100,6 +1168,10 @@
         <source>In:</source>
         <translation>در:</translation>
     </message>
+    <message>
+        <source>Out:</source>
+        <translation>خروجی:</translation>
+    </message>
     <message>
         <source>Debug log file</source>
         <translation>فایلِ لاگِ اشکال زدایی</translation>
@@ -1108,6 +1180,26 @@
         <source>Clear console</source>
         <translation>پاکسازی کنسول</translation>
     </message>
+    <message>
+        <source>1 &amp;hour</source>
+        <translation>1 ساعت</translation>
+    </message>
+    <message>
+        <source>1 &amp;day</source>
+        <translation>1 روز</translation>
+    </message>
+    <message>
+        <source>1 &amp;week</source>
+        <translation>1 هفته</translation>
+    </message>
+    <message>
+        <source>1 &amp;year</source>
+        <translation>1 سال</translation>
+    </message>
+    <message>
+        <source>Ban for</source>
+        <translation>محدود شده برای</translation>
+    </message>
     <message>
         <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
         <translation>دکمه‌های بالا و پایین برای پیمایش تاریخچه و &lt;b&gt;Ctrl-L&lt;/b&gt; برای پاک کردن صفحه.</translation>
@@ -1348,6 +1440,14 @@
         <source>Copy fee</source>
         <translation>رونوشت کارمزد</translation>
     </message>
+    <message>
+        <source>Copy bytes</source>
+        <translation>کپی کردن بایت ها</translation>
+    </message>
+    <message>
+        <source>Copy change</source>
+        <translation>کپی کردن تغییر</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(بدون برچسب)</translation>
@@ -1558,6 +1658,10 @@
         <source>Address</source>
         <translation>آدرس</translation>
     </message>
+    <message>
+        <source>Exporting Failed</source>
+        <translation>صدور موفق نبود</translation>
+    </message>
     </context>
 <context>
     <name>UnitDisplayStatusBarControl</name>
